powered by
Convert kth indexes to ij indexes of a dist object
dist_k_ij(k, size)
kth indexes
value of size attribute of the dist object
ij indexes as 2*n matrix where n is length of k vector
# NOT RUN { dist_k_ij(4:6, 10:12) # }
Run the code above in your browser using DataLab